#
# spec file for package smemstat
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2017, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           smemstat
Version:        0.02.07
Release:        lp152.1.3
Summary:        Memory usage monitoring tool
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://kernel.ubuntu.com/~cking/smemstat/
Source:         https://kernel.ubuntu.com/~cking/tarballs/%{name}/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(ncursesw)

%description
Smemstat reports the physical memory usage taking into consideration shared
memory. The tool can either report a current snapshot of memory usage or
periodically dump out any changes in memory.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Benchmark
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (smemstat and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash completion script for %{name}.

%prep
%setup -q

%build
export CFLAGS="%{optflags} $(pkg-config --cflags ncursesw) -fwhole-program"
%make_build

%install
%make_install

%files
%license COPYING
%{_bindir}/smemstat
%{_mandir}/man8/smemstat.8%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Sun Mar  8 2020 Martin Hauke <mardnh@gmx.de>
- Supplement against bash-completion, not bash
* Sun Mar  8 2020 Martin Hauke <mardnh@gmx.de>
- Drop SLE12 compat ifdef
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.07
  * Add bash completion script
* Tue Dec 17 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.06
  * Format Total: field using the size of the pid fields to fix
    alignment
  * Add sanity check on tmp before dereferencing it
  * Fix potential memory leak when re-assigning new cmdline
* Tue Aug 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.05
  * No functional changes
* Sun Jul  7 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.04
  * Manual: fix typo: comsumers -> consumers
  * Update copyright year
* Sat Jan 12 2019 mardnh@gmx.de
- Update to version 0.02.03
  * Don't emit "Note: Mmeory reported in units..." message in quiet mode
  * Don't emit Change in memory message in quiet mode
  * Make structs pack more efficiently
* Mon Nov 26 2018 Cristian Rodríguez <crrodriguez@opensuse.org>
- Use the correct set of ncurses headers, find ncursesw includes
  with pkg-config
* Tue Jul 10 2018 mardnh@gmx.de
- Update to version 0.02.01
  * Makefile: bump version
  * debian/watch: look for .xz suffixed tarball
  * Makefile: make .xz tarball for better compression
  * Add .travis.yml file to make dist rule
  * Add more constifications
  * don't show arrow in one-shot mode
  * Fix up some whitespacing
  * Add some more constifications
  * Voidify function returns
  * snapcraft: add stage-packages entry
  * debian/control: add libncurses-dev
  * Add travis yaml file
  * snapcraft: add libncursesw5-dev
* Thu Jun 14 2018 mardnh@gmx.de
- Update to version 0.02.00
  * Makefile: bump version
  * debian/control: change build depends, now use libncurses5w-dev
  * debian/control: update debhelper to version 11 or higher
  * debian/compat: update to 11
  * debian/copyright: use secure URI
  * debian/control: remove trailing empty line
  * Makefile: use ncursesw for utf-8
  * Add delta field showing change in memory with -T option
  * Make snapcraft stable
  * snapcraft: update interfaces
  * snapcraft: make confinement strict
  * Make some index variables size_t
* Fri Jan  5 2018 mardnh@gmx.de
- update to version 0.01.18
  * Makefile: bump version
  * debian/rules: remove whitespace at end of line
  * Bump copyright year to 2018
  * debian/control: update Standards-Version to 4.1.2
  * Remove packed attribute from various structs
  * snapcraft: add default app and stable keys
  * snapcraft: Makefile: remove icon hack
* Wed May 10 2017 mardnh@gmx.de
- update to version 0.01.17
  * Makefile: bump version
  * Manual: update copyright year and manual date
  * Makefile: add snapcraft to make dist rule
  * Add variable pid size handling.
  * Update copyright year
  * Add system-observe plug to snapcraft rules
- update to version 0.01.16
  * Makefile: bump version
  * Add some more trivial comments
  * Remove unnecessary static NULL assignments
  * Add gnu printf attributes
  * Clean up code
  * Remove need for linebreak display function
  * Debain/control: add libncurses5-dev
  * Update manual
  * Add ncurses -t and -T top modes
  * Makefile: add PEDANTIC flags
- update to version 0.01.15
  * Makefile: bump version
  * Debian/control: update Build-Depends for debhelper
  * Debian/compat: update to 9
  * Debian/control: update Standards-Version to 3.9.8
  * Update and correct copyright years
* Wed Nov 11 2015 mardnh@gmx.de
- initial package
